==> octave_7.3.0.orig.tar.xz: octave-7.3.0/libgui/graphics/BaseControl.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2011-2022 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if ! defined (octave_BaseControl_h)
#define octave_BaseControl_h 1

#include "Object.h"

class QEvent;
class QObject;

namespace octave
{
  class base_qobject;
  class interpreter;
}

namespace octave
{

  class BaseControl : public Object
  {
  public:
    BaseControl (octave::base_qobject& oct_qobj, octave::interpreter& interp,
                 const graphics_object& go, QWidget *w);
    ~BaseControl (void);

    Container * innerContainer (void) { return nullptr; }

    bool eventFilter (QObject *watched, QEvent *e);

  protected:
    void init (QWidget *w, bool callBase = false);
    void redraw (void);
    void update (int pId);

  private:
    bool m_normalizedFont;
    bool m_keyPressHandlerDefined;
  };

}

#endif

==> octave_11.0.90.orig.tar.xz: octave-11.0.90/libgui/graphics/BaseControl.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2011-2026 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if ! defined (octave_BaseControl_h)
#define octave_BaseControl_h 1

#include "Object.h"

class QEvent;
class QObject;

OCTAVE_BEGIN_NAMESPACE(octave)

class interpreter;

class BaseControl : public Object
{
public:
  BaseControl (octave::interpreter& interp,
               const graphics_object& go, QWidget *w);
  ~BaseControl ();

  Container * innerContainer () { return nullptr; }

  bool eventFilter (QObject *watched, QEvent *e);

protected:
  void init (QWidget *w, bool callBase = false);
  void redraw ();
  void update (int pId);

private:
  bool m_normalizedFont;
  bool m_keyPressHandlerDefined;
};

OCTAVE_END_NAMESPACE(octave)

#endif
